@@ -489,8 +489,10 @@ __attribute__((warn_unused_result)) int Transcribe1AlgEqn(PFILE pfile, PVMMAPSTR
         Rprintf("Exiting...\n\n");
         return EXIT_ERROR;
       }
-      snprintf(szTmpEqSwap, len, "%s%s%s", szTmpEq, pV->szName, szLex); /* extend */
-      strncpy(szTmpEq, szTmpEqSwap, len);
+      // because of the check above we ensure we will be under MAX_EQN 
+      // so the following operations will always emit non negative values
+      strncat(szTmpEq, pV->szName, MAX_EQN - strlen(szTmpEq) - 1);
+      strncat(szTmpEq, szLex, MAX_EQN - strlen(szTmpEq) - 1);
     } else {
       int len = strlen(szTmpEq) + 1 + strlen(szLex) + 1;
       if (len > MAX_EQN) {
@@ -575,8 +577,11 @@ __attribute__((warn_unused_result)) int Transcribe1DiffEqn(PFILE pfile, PVMMAPST
         Rprintf("Exiting...\n\n");
         return EXIT_ERROR;
       }
-      snprintf(szTmpEqSwap, len, "%s%s%s", szTmpEq, pV->szName, szLex); /* extend */
-      strncpy(szTmpEq, szTmpEqSwap, len);
+      // because of the check above we ensure we will be under MAX_EQN 
+      // so the following operations will always emit non negative values
+      strncat(szTmpEq, pV->szName, MAX_EQN - strlen(szTmpEq) - 1);
+      strncat(szTmpEq, szLex, MAX_EQN - strlen(szTmpEq) - 1);
+
     } else {
       int len = strlen(szTmpEq) + 1 + strlen(szLex) + 1;
       if (len > MAX_EQN) {
